describe('Servicios modulo crear hoja de ruta', function() {

    beforeEach(function() {
        module('focaCrearHojaRuta');
        inject(module(function($provide) {
            $provide.value('API_ENDPOINT', {
                URL: 'localhost'
            });
        }));
    });

    describe('Servicio focaCrearHojaRutaService', function() {

        var servicio;
        var httpBackend;

        beforeEach(function() {
            inject(function($httpBackend, _focaCrearHojaRutaService_) {
                httpBackend = $httpBackend;
                servicio = _focaCrearHojaRutaService_;
            });
        });

        it('Existe el servicio focaCrearHojaRutaService', function() {

            //assert
            expect(typeof servicio).toEqual('object');
        });

        it('función crearHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;
            var paramFake = 'test';

            httpBackend.expectPOST('localhost/hoja-ruta', paramFake).respond(responseFake);

            //act
            servicio.crearHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función obtenerHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;

            httpBackend.expectGET('localhost/hoja-ruta').respond(responseFake);

            //act
            servicio.obtenerHojaRuta().then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función setHojaRuta llama ruta correcta', function() {

            //arrange
            var paramFake = 'paramFake';

            //act
            servicio.setHojaRuta(paramFake);

            //assert
            expect(servicio.hojaRuta).toEqual(paramFake);
        });

        it('función clearHojaRuta llama ruta correcta', function() {

            //act
            servicio.clearHojaRuta();

            //assert
            expect(servicio.hojaRuta).toEqual(undefined);
        });

        it('función getHojaRuta llama ruta correcta', function() {

            //arrange
            var esperado = 'unit test';
            servicio.hojaRuta = esperado;

            //act
            var resultado = servicio.getHojaRuta();

            //assert
            expect(resultado).toEqual(esperado);
        });

        it('función getArticulosByIdHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param fake';
            var result;

            httpBackend.expectGET('localhost/articulos/hoja-ruta/' + paramFake)
                .respond(responseFake);

            //act
            servicio.getArticulosByIdHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función crearArticulosParaHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param fake';
            var result;

            httpBackend.expectPOST('localhost/articulos/hoja-ruta',
                { articuloHojaRuta: paramFake }).respond(responseFake);

            //act
            servicio.crearArticulosParaHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getDomiciliosByIdHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectGET('localhost/hoja-ruta/' + paramFake + '/domicilios')
                .respond(responseFake);

            //act
            servicio.getDomiciliosByIdHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getDomiciliosByIdCliente llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectGET('localhost/domicilio/tipo/2/cliente/' + paramFake )
                .respond(responseFake);

            //act
            servicio.getDomiciliosByIdCliente(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getPrecioCondicion llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;

            httpBackend.expectGET('localhost/precio-condicion')
                .respond(responseFake);

            //act
            servicio.getPrecioCondicion().then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getPrecioCondicionById llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectGET('localhost/precio-condicion/' + paramFake)
                .respond(responseFake);

            //act
            servicio.getPrecioCondicionById(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getPlazoPagoByPrecioCondicion llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectGET('localhost/plazo-pago/precio-condicion/' + paramFake)
                .respond(responseFake);

            //act
            servicio.getPlazoPagoByPrecioCondicion(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función crearFlete llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectPOST('localhost/flete', { flete: paramFake })
                .respond(responseFake);

            //act
            servicio.crearFlete(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función crearPlazosParaHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectPOST('localhost/plazo-pago/hoja-ruta', paramFake)
                .respond(responseFake);

            //act
            servicio.crearPlazosParaHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getCotizacionByIdMoneda llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectGET('localhost/moneda/' + paramFake)
                .respond(responseFake);

            //act
            servicio.getCotizacionByIdMoneda(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función crearEstadoParaHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param-fake';
            var result;

            httpBackend.expectPOST('localhost/estado', { estado: paramFake})
                .respond(responseFake);

            //act
            servicio.crearEstadoParaHojaRuta(paramFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getNumeroHojaRuta llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var result;

            httpBackend.expectGET('localhost/hoja-ruta/numero-siguiente')
                .respond(responseFake);

            //act
            servicio.getNumeroHojaRuta().then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función getRemitosByIdVehiculo llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param fake';
            var dateFake = new Date();
            var result;

            httpBackend.expectGET('localhost/vehiculo/obtener/remitos/' + paramFake + '/' +
                dateFake.toISOString().substring(0, 10))
                .respond(responseFake);

            //act
            servicio.getRemitosByIdVehiculo(paramFake, dateFake).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });

        it('función desasociarRemitos llama ruta correcta', function() {

            //arrange
            var responseFake = 'responseFake';
            var paramFake = 'param fake';
            var paramFake2 = 'param fake 2';
            var paramFake3 = 'param fake 3';
            var result;

            httpBackend.expectPOST('localhost/vehiculo/desasociar-remitos',
            {
                idsRemitos: paramFake,
                idVehiculo: paramFake2,
                vehiculoSinRemitos: paramFake3
            }).respond(responseFake);

            //act
            servicio.desasociarRemitos(paramFake, paramFake2, paramFake3).then(function(data) {
                result = data.data;
            });
            httpBackend.flush();

            //assert
            expect(result).toEqual(responseFake);
        });
    });
});
